==> haskell-descriptive-0.9.4-54-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-1uEao130n3v97KQnUEJr7N
key: descriptive-0.9.4-1uEao130n3v97KQnUEJr7N
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: a737e63031869ad07e1d97feee40655f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/descriptive-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-1uEao130n3v97KQnUEJr7N
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY base-4.9.1.0
    bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    scientific-0.3.4.15-Is44CvKqXBF5ugVqyS94hI
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-56-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-3W00goQPY5v2V9Zg2kUr3E
key: descriptive-0.9.4-3W00goQPY5v2V9Zg2kUr3E
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 948aa20b56964037d3c22df2b9894c3f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/descriptive-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-3W00goQPY5v2V9Zg2kUr3E
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9 base-4.9.1.0
    bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    scientific-0.3.5.0-7hRLtQzMvnkCQbsJuyPHcq
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
